@@ -4,25 +4,25 @@ from selenium.common.exceptions import NoSuchElementException, TimeoutException,
 from selenium.webdriver.support import expected_conditions as EC
 import time
 import os
+import logging as logger
 from selenium.webdriver.common.by import By
 from selenium.webdriver.common.keys import *
-from helpers.driver_manager import logger, driver, driver_wait, current_os, create_driver_instance
+from helpers.driver_manager import create_driver, create_wait, current_os
 
 """Class that wraps selenium functions to be used in UI automation tests
 """
 
 wait_msg = "Locator --> {}"
-driver = create_driver_instance().get_driver()
-_driver_wait = create_driver_instance().get_wait()
-wait = create_driver_instance().get_wait()
-
-
-# def __init__(driver: WebDriver, wait: WebDriverWait):
-#     driver: WebDriver = driver
-#     wait = wait
-#     _driver_wait: WebDriverWait = wait
+_driver_wait = None
 
 
+def create_driver_instance(browser_type, run_mode):
+    global driver
+    global _driver_wait
+    driver = create_driver(browser_type, run_mode)
+    _driver_wait = create_wait()
+    
+    
 class WaitForDocReady(object):
     """Class that allows to verify if the document (page) is loaded
     """
@@ -47,14 +47,13 @@ def _setup_wrapper(wait_time=None, wait_for_load=False):
         wait_time (float, optional): Optional wait time if the default wait want to be skipped. Defaults to None.
         wait_for_load (bool, optional): Allow to wait for the page to load. Defaults to False.
     """
+    global  _driver_wait
     # If wait time is specified it doesn't affect the wait for doc ready
     if wait_for_load:
-        wait.until(WaitForDocReady())
+        _driver_wait.until(WaitForDocReady())
     if wait_time:
         ignored_exceptions = (StaleElementReferenceException,)
         _driver_wait = WebDriverWait(driver, wait_time, ignored_exceptions=ignored_exceptions)
-    else:
-        _driver_wait = wait
 
 
 """
@@ -1426,7 +1425,7 @@ def send_arrow_down_key(locator, elem_name, wait_time=None):
         wait_time (float, optional): custom wait time for the elements, skips driver default wait time
     """
     _setup_wrapper(wait_time, wait_for_load=True)
-    elem = driver_wait.until(EC.visibility_of_element_located((locator[0], locator[1])),
+    elem = _driver_wait.until(EC.visibility_of_element_located((locator[0], locator[1])),
                              wait_msg.format(locator))
     elem.send_keys(Keys.ARROW_DOWN)
     logger.info(f"Arrow down was pressed on {elem_name}")
